NAME = "story.py"
ORIGINAL_AUTHORS = ["Tuan Thai"]

ABOUT = """
Sends a random story
Sourced stories from
http://www.read.gov/aesop/001.html
"""

COMMANDS = """
>>> .story
returns random story
"""

WEBSITE = ""
