NAME = "movies_imdb.py"
ORIGINAL_AUTHORS = ["Zoi Katsantoni"]

ABOUT = """
returns a certain information about a movie from IMDb
eg. cast, directors,...
"""

COMMANDS = """
>>> .movies_imdb <<search>> <<movie>> <<information>>
returns the information for the movie
.movies_imdb 250movies
returns 250 all-time most popular movies
"""

WEBSITE = ""
