NAME = "monopoly.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Play monopoly
"""

COMMANDS = """
>>>.monopoly create
creates monopoly

>>>.monopoly join
user joins the game

>>>.monopoly start
starts the game

>>>.monopoly roll
rolls two dice to see how far the user will move/if the user can leave the jail

>>>.monopoly buy
user purchases property if unowned, otherwise buys house

>>>.monopoly pass
user passes on the opportunity to buy a property if unowned,
or on the opportunity to buy a house

>>>.monopoly leave
user leaves the game

>>>.monopoly help
sends messages explaining how to use the monopoly plugin

>>>.monopoly info
sends messages showing the status of each player

.monopoly info rolls
displays basic information about the upcoming spaces in front of a player

.monopoly info <<player>>
shows information about a certain player

.monopoly info <<property>>
shows information about a property
"""

WEBSITE = ""
