NAME = "debug.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
prints all parameters passed to bot
"""

COMMANDS = """
>>> .debug
prints some parameters
"""

WEBSITE = ""
