NAME = "send_message.py"
ORIGINAL_AUTHORS = ["Justin Walker"]

ABOUT = """
Sends a message to another channel.
"""

COMMANDS = """
>>> .send #channel .u riceabove .m how are you?
Sends a message to #channel like
'IronPenguin from #channel says to riceabove: how are you?'

>>> .send #channel hi all
Sends a message to #channel like
'IronPenguin from #channel says: hi all'

Checks if user online first and says "User not online."
"""

WEBSITE = ""
