NAME = "todo.py"
ORIGINAL_AUTHORS = ["Himanshu Ranjan"]

ABOUT = """
Todo list keeps all your pending task .
You can add a task ,delete or show list.
This list is stored in a text file called todo.txt in honeybot directory.
If this does not exist it creates one.
"""

COMMANDS = """
>>>.todo add <Your Task Here>
It adds the task to do the todo list.

>>>.todo delete <index>
To delete a task input it's index number as shown in the list.

>>>.todo show
It shows all the task currently on the list.

>>>.todo clear
This will delete all the task in the list.

>>>.todo help
sends messages explaining how to use the todo plugin
"""

WEBSITE = "https://github.com/h-ranjan1110"
