NAME = "Birthday Paradox"

ORIGINAL_AUTHORS = ["Paulo Ferraz"]

ABOUT = """
Show the probability that two or more people
have the same birthday in the given group.
"""

COMMANDS = """
>>> .birth
returns help on plugin use

>>> .birth <<number>>
returns the birthday matches and probability in %.
"""
