NAME = "memo.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
responds to .memo, demo of a basic memory plugin
"""

COMMANDS = """
>>> .memo add <key> <value>
>>> .memo rem <key>
>>> .memo fetch <key>
"""

WEBSITE = ""
