NAME = "fact.py"
ORIGINAL_AUTHORS = ["Justin Walker"]

ABOUT = """
Returns a random fact.
Facts sourced from Mental Floss
http://mentalfloss.com/article/55443/101-amazing-facts
"""

COMMANDS = """
>>> .fact
returns random fact
"""

WEBSITE = ""
