NAME = "news.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Gets the top 10 headlines around the world from bbc world news
"""

COMMANDS = """
>>> .news
returns string of ten news headlines with newlines between
"""

WEBSITE = ""
