NAME = "weather.py"
ORIGINAL_AUTHORS = ["Gabriele Ron"]

ABOUT = """
A plugin to get the weather of a location
"""

COMMANDS = """
>>> .weather <city> <country code>
returns the weather
"""

WEBSITE = ""
