NAME = "diary.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Keeps a record of your diary
"""

COMMANDS = """
>>>.diary record <diary entry>
Adds to that day's diary entry

>>>.diary show <date>
Will show the diary entry of specified date (can also accept "today", "yesterday")

>>>.diary delete
Will delete today's entry

>>>.diary help
Gives help about how to use the plugin
"""

WEBSITE = ""
