NAME = "converter.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Converts currencies
"""

COMMANDS = """
>>> .convert <<base currency code>> <<target currency code>> <<amount>>
returns the conversion: amount argument is optional with a default of 1
.convert help
shows a list of currencies supported
"""

WEBSITE = ""
