NAME = "dadjoke.py"
ORIGINAL_AUTHORS = ["moffetma Oregon State University CS"]

ABOUT = """
Sends a random "dad joke" from icanhazdadjoke.com
"""

COMMANDS = """
>>> .dadjoke
Have you heard of the band 1023MB? They haven't got a gig yet.
"""

WEBSITE = ""
