NAME = "translate.py"
ORIGINAL_AUTHORS = ["Ahmed Deeb"]

ABOUT = """
A Google Translate plugin
"""

COMMANDS = """
>>> . Google Translator object.

Examples
--------
translator = Plugin()

results1 = translator.translate("Einen schönen Tag allerseits")

# try 2 at a time
results2 = translator.translate(["Einen schönen Tag allerseits",
"Ich nehme an"])

# try detect
results3 = translator.detect("Einen schönen Tag allerseits")

# try to detect 2 at a time
results4 = translator.detect(["Einen schönen Tag allerseits",
"Ich nehme an"])
"""

WEBSITE = ""
