NAME = "conv_sniff.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
senses conversation topic with sensitivity set by user, also supports
word-specific sensing
"""

COMMANDS = """

"""

WEBSITE = ""
