NAME = "dictionary.py"
ORIGINAL_AUTHORS = ["Milad H,"]

ABOUT = """
Searches the python documentatioin(pydocs) for the related keyword(s)
and returns some of the relevant links
"""

COMMANDS = """
>>> .pydocs <keyword>
returns links in python documentation related to the keyword
"""

WEBSITE = ""
