NAME = "book_of_day.py"

ORIGINAL_AUTHORS = ["Schoberg", "UMD"]

ABOUT = """book_of_day
Using bookoftheday.org, get the title and link of the book of the day
"""

COMMANDS = """
>>> .bookoftheday
https://bookoftheday.org/fleishman-is-in-trouble-taffy-brodesser-akner/
"""
