NAME = "username.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
generates random usernames, used for inspiration
"""

COMMANDS = """
>>> .uname
returns generated username
"""

WEBSITE = ""
