NAME = "hangman.py"
ORIGINAL_AUTHORS = ["Justin Walker"]

ABOUT = """
Plays game of hangman
"""

COMMANDS = """
>>> .hangman start
Starts hangman game and returns game screen.

>>> .hangman guess <<word or letter>>
Submits word or letter guess and returns game screen.
"""

WEBSITE = ""
