NAME = "help.py"
ORIGINAL_AUTHORS = ["Eduardo Moraes de Mello, https://github.com/edumello"]

ABOUT = """
Show link with all the functionalities of the bot.
"""

COMMANDS = """
>>> .help
returns link of plugins informations
"""

WEBSITE = ""
