NAME = "password_generator.py"
ORIGINAL_AUTHORS = ["Nishant, JPMorgan Chase & Co."]

ABOUT = """
sends different type of passwords
"""

COMMANDS = """
>>> .passgen <<length>>
returns alphabetic password of specified length

>>> .passgensecure <<length>>
returns secure alphanumeric password of specified length

>>> .passgenalphanum <<length>>
returns alphanumeric password of specified length

>>> .passgenspecialchar <<length>>
returns universally accepted alphanumeric password
with special characters of specified length where length >= 4
"""

WEBSITE = ""
