NAME = "date.py"
ORIGINAL_AUTHORS = ["Gico Carlo Evangelista, https://gicocarlo.me/"]

ABOUT = """
Will post the current date
"""

COMMANDS = """
>>> .date today
returns the current date
"""

WEBSITE = ""
