NAME = "magic_ball.py"
ORIGINAL_AUTHORS = ["Zakaria Talhami"]

ABOUT = """
Fortune-telling for question using a magic 8 ball
"""

COMMANDS = """
>>> .8ball <<question>>
returns It is certain

>>> .magic8ball <<question>>
returns Very doubtful
"""

WEBSITE = ""
