NAME = "googlesearch.py"
ORIGINAL_AUTHORS = ["Justin Walker"]

ABOUT = """
Returns the first three links from a google search.
"""

COMMANDS = """
>>> .google <<search term>>
returns search links
"""

WEBSITE = ""
