NAME = "Caesar Cipher"
ORIGINAL_AUTHORS = ["Kyle Galloway"]

ABOUT = """
encrypts and decrypts using a caesar cipher
"""

COMMANDS = """
>>> .caesar_cipher <message>
returns the encrypted version of message
"""

WEBSITE = ""
