NAME = "channeljoin.py"
ORIGINAL_AUTHORS = ["Marcelo Benesciutti"]

ABOUT = """
Bot Will join a given channel in the server
"""

COMMANDS = """
>>> .channeljoin channel
bot joins the given channel
"""

WEBSITE = ""
