NAME = "blackjack.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Play blackjack
"""

COMMANDS = """
>>>.blackjack create
creates blackjack game

>>>.blackjack join
join blackjack game

>>>.blackjack start
start a round

>>>.blackjack hit
get another card

>>>.blackjack stand
move on to next player
"""
