NAME = "dictionary.py"
ORIGINAL_AUTHORS = ["Nishant, JPMorgan Chase & Co."]

ABOUT = """
sends the meaning of the word
requires PyDictionary to be installed
can use pip -> "pip install PyDictionary"
"""

COMMANDS = """
>>> .dictionary <<word>>
returns meaning of the word specified
"""

WEBSITE = ""
