NAME = "russian_roulette.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
In the original russian roulette, you have a one sixth chance of committing
suicide. In this version, you have a one sixth chance of being kicked from
the channel. The bot will utilise the IRC command:
KICK #channel nickname
where #channel is the channel name and nicknames is the nickname of the user
"""

COMMANDS = """
>>> .russian_roulette
either returns a string saying you survived or kicks you off the channel
"""

WEBSITE = ""
