NAME = "url_shorten.py"
ORIGINAL_AUTHORS = ["Rakesh Seal"]

ABOUT = """
Shorten an url with cleanuri and returns the smaller url.
"""

COMMANDS = """
>>> .url_shorten <url>
Shorten an url with cleanuri and returns the smaller url.
"""
