NAME = "maths.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
some maths related commands
"""

COMMANDS = """
>>> .sin <number>
returns sine of number

>>> .cos <number>
returns cosine of number

>>> .tan <number>
returns tangent of number

>>> .rand <number1> <number2>
returns number between number1 and number2
"""

WEBSITE = ""
