NAME = "Self Travia"
ORIGINAL_AUTHORS = ["Angel Jimenez"]

ABOUT = """
Returns a private trivia question
"""

COMMANDS = """
>>> .selfTrivia
returns a random question
Currently working on adding multiple choice and a timer reveal.
"""

WEBSITE = ""
