NAME = "sysinfo.py"
ORIGINAL_AUTHORS = ["Girish Mahabir"]

ABOUT = """
Responds to .sysinfo, gets System Information of the host.
"""

COMMANDS = """
>>> .sysinfo
returns General System Information, Boot Date and time, CPU information,
Memory information, Disk Information and Network Information.
"""

WEBSITE = ""
