NAME = "basketball.py"

ORIGINAL_AUTHORS = ["Konstantinos Efthymiadis"]

ABOUT = """
Given the event and year as parameters, the plugin will return the countries that won the medal that year
Given the event and country as parameters, the plugin will return the number of medals this country has won
"""

COMMANDS = """
>>> .basketball <<event>> <<year/country>>
returns a string with all the information
>>> .basketball <<event>> <<all>>
returns a table with all the medals of all the years
"""
