NAME = "Roman Numeral Converter Plugin"
ORIGINAL_AUTHORS = ["Nick Wiley"]

ABOUT = """
Returns the roman numeral equivalent of the number inputted
"""

COMMANDS = """
>>> .roman <number>
returns number represented in roman numerals
"""

WEBSITE = ""
