NAME = "countries.py"
ORIGINAL_AUTHORS = ["Sarvesh Dubey"]

ABOUT = """
Show the dialcode of a given country.
"""

COMMANDS = """
>>> .tel <country_code>
returns the associated country telephone code
"""

WEBSITE = ""
