NAME = "duck.py"
ORIGINAL_AUTHORS = ["Rakesh Seal"]

ABOUT = """
Returns a abstract of the search query from a duckduckgo Search. Return empty if no abstract found.
"""

COMMANDS = """
>>> .duck <query>
returns abstrack from duckduckgo search
"""
