NAME = "riddle.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Returns a riddle or whether guess at the answer was correct or not.
"""

COMMANDS = """
>>> .riddle
returns a random riddle

.riddle guess <<attempt>>
returns whether the guess was correct or wrong
"""

WEBSITE = ""
