NAME = "pynews.py"
ORIGINAL_AUTHORS = ["Sam Deans"]

ABOUT = """
Finds the top five news items on python.org and prints them to the IRC
"""

COMMANDS = """
>>> .pynews
returns the top 5 python.org news articles
"""

WEBSITE = ""
