NAME = "installed_module.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
checks if all listed in requirements.txt installed
"""

COMMANDS = """
>>> .installed
"""

WEBSITE = ""
