NAME = "random_color.py"
ORIGINAL_AUTHORS = ["Jeet Trivedi"]

ABOUT = """
responds to .randcol, returns a HEX color code
"""

COMMANDS = """
>>> .randcol
returns a HEX color code: a 6-character string representing RGB
"""

WEBSITE = ""
