NAME = "bitcoin.py"

ORIGINAL_AUTHORS = ["Gabriele Ron"]

ABOUT = """
Checks the current price for Bitcoin through the Legacy Coin Market Cap API
TODO: Update API to new Coin Market Cap API
"""

COMMANDS = """
>>> .btc
returns current value of bitcoin
"""

WEBSITE = "https://Macr0Nerd.github.io"
