NAME = "roll.py"
ORIGINAL_AUTHORS = ["Glenn Toms"]

ABOUT = """
Will roll dice in the form of 1d4, 10d6 and return total.
"""

COMMANDS = """
>>> .roll <<dice>>
returns Total of dice
"""

WEBSITE = ""
