NAME = "calc.py"
ORIGINAL_AUTHORS = ["Abdur-Rahmaan Janhangeer, pythonmembers.club"]

ABOUT = """
evaluates maths expressions in the format supported by py
"""

COMMANDS = """
>>> .calc <maths expression>
returns evaluated expression
"""

WEBSITE = ""
