NAME = "corona.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
provides information about the coronavirus pandemic
"""

COMMANDS = """
>>> .corona
returns global coronavirus information

.corona <<country>>
returns coronavirus information for a specific country
"""

WEBSITE = ""
