NAME = "horoscope.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Returns your daily horoscope based on your star sign
you can also enter your month and date of birth to automatically find your starsign
enter month and date as number
"""

COMMANDS = """
>>> .horoscope <<starsign>>
returns horoscope for starsign

.horoscope <<month>> <<day>>
returns horoscope for starsign of day entered
"""

WEBSITE = ""
