NAME = "monero.py"
ORIGINAL_AUTHORS = ["A. Eigenbrot"]

ABOUT = """
Checks the current price for Monero via the cryptocompare.com API
"""

COMMANDS = """
>>> .xmr [currency]
returns current value of Monero in the currency specified (default is USD).
Currency must be a 3-letter capital string.
Examples: USD, EUR, BTC, GBP
"""

WEBSITE = ""
