NAME = "wikipedia.py"
ORIGINAL_AUTHORS = ["Gabriele Ron"]

ABOUT = """
sends a wikipedia article on request based off of a search or random query
requires wikipedia library. Can use pip -> "pip install wikipedia"
"""

COMMANDS = """
>>> .wiki <command> <topic>
returns a wikipedia article
"""

WEBSITE = "https://Macr0Nerd.github.io"
