NAME = "transfer-rumour.py"
ORIGINAL_AUTHORS = ["Angelo Giacco"]

ABOUT = """
Collects transfer rumours from BBC sport
"""

COMMANDS = """
>>> .transfer-rumour
prints the top transfer rumour
"""

WEBSITE = ""
