NAME = "repostats.py"
ORIGINAL_AUTHORS = ["Shreyansh Sancheti"]

ABOUT = """
Gets the number of forks and stars for a given repo
"""

COMMANDS = """
>>> .repostats url
returns starcount stars | forkcount forks
"""

WEBSITE = ""
